==> Automatic_Train_Painter_1.2.0.zip: Automatic_Train_Painter_1.2.0/settings.lua <==
data:extend({
    {
        type = "bool-setting",
        name = "paint-loco",
        order = "aa",
        setting_type = "runtime-global",
        default_value = true,
    },
    {
        type = "bool-setting",
        name = "paint-cargo-wagon",
        order = "ab",
        setting_type = "runtime-global",
        default_value = false,
    },
	{
        type = "bool-setting",
        name = "paint-fluid-wagon",
        order = "ac",
        setting_type = "runtime-global",
        default_value = false,
    },
	{
        type = "bool-setting",
        name = "unpaint-empty",
        order = "ad",
        setting_type = "runtime-global",
        default_value = true,
    },
    {
        type = "string-setting",
        name = "u-loco",
        order = "ba",
        setting_type = "runtime-global",
        default_value = "E4D1C7",
        allow_blank = "true",
    },
    {
        type = "string-setting",
        name = "u-cargo-wagon",
        order = "bb",
        setting_type = "runtime-global",
        default_value = "6D3A00",
        allow_blank = "true",
    },
    {
        type = "string-setting",
        name = "u-fluid-wagon",
        order = "bc",
        setting_type = "runtime-global",
        default_value = "C8C8C8",
        allow_blank = "true",
    },
    {
        type = "bool-setting",
        name = "atp-ltn-paint",
        order = "ca",
        setting_type = "runtime-global",
        default_value = false,
    },
    {
        type = "string-setting",
        name = "atp-custom-colors-enable",
        order = "cb",
        setting_type = "runtime-global",
        default_value = "Off",
        allowed_values = {"Off","Priority","Only"}
    },
    {
        type = "string-setting",
        name = "atp-custom-colors-list",
        order = "cc",
        setting_type = "runtime-global",
        default_value = "",
        allow_blank = "true",
    },
    {
        type = "bool-setting",
        name = "loc-eqpm-grid",
        order = "da",
        setting_type = "startup",
        default_value = false,
    },
    {
        type = "int-setting",
        name = "loc-eqpm-grid-w",
        order = "db",
        setting_type = "startup",
        minimum_value = 2,
        default_value = 2,
        maximum_value = 16
    },
    {
        type = "int-setting",
        name = "loc-eqpm-grid-h",
        order = "dc",
        setting_type = "startup",
        minimum_value = 2,
        default_value = 4,
        maximum_value = 16
    }
})

==> Automatic_Train_Painter_2.0.1.zip: Automatic_Train_Painter_2.0.1/settings.lua <==
data:extend({
    {
        type = "bool-setting",
        name = "paint-loco",
        order = "aa",
        setting_type = "runtime-global",
        default_value = true,
    },
    {
        type = "bool-setting",
        name = "paint-cargo-wagon",
        order = "ab",
        setting_type = "runtime-global",
        default_value = true,
    },
	{
        type = "bool-setting",
        name = "paint-fluid-wagon",
        order = "ac",
        setting_type = "runtime-global",
        default_value = true,
    },
	{
        type = "bool-setting",
        name = "unpaint-empty",
        order = "ad",
        setting_type = "runtime-global",
        default_value = true,
    },
    {
        type = "string-setting",
        name = "u-loco",
        order = "ba",
        setting_type = "runtime-global",
        default_value = "E4D1C7",
        allow_blank = true,
    },
    {
        type = "string-setting",
        name = "u-cargo-wagon",
        order = "bb",
        setting_type = "runtime-global",
        default_value = "6D3A00",
        allow_blank = true,
    },
    {
        type = "string-setting",
        name = "u-fluid-wagon",
        order = "bc",
        setting_type = "runtime-global",
        default_value = "C8C8C8",
        allow_blank = true,
    },
    --{
    --    type = "bool-setting",
    --    name = "atp-ltn-paint",
    --    order = "ca",
    --    setting_type = "runtime-global",
    --    default_value = false,
    --},
    {
        type = "string-setting",
        name = "atp-custom-colors-enable",
        order = "cb",
        setting_type = "runtime-global",
        default_value = "Off",
        allowed_values = {"Off","Priority","Only"}
    },
    {
        type = "string-setting",
        name = "atp-custom-colors-list",
        order = "cc",
        setting_type = "runtime-global",
        default_value = "",
        allow_blank = true,
    },
    {
        type = "bool-setting",
        name = "loc-eqpm-grid",
        order = "da",
        setting_type = "startup",
        default_value = false,
    },
    {
        type = "int-setting",
        name = "loc-eqpm-grid-w",
        order = "db",
        setting_type = "startup",
        minimum_value = 2,
        default_value = 2,
        maximum_value = 16
    },
    {
        type = "int-setting",
        name = "loc-eqpm-grid-h",
        order = "dc",
        setting_type = "startup",
        minimum_value = 2,
        default_value = 4,
        maximum_value = 16
    }
})
